import { resolve } from 'path'
import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue2'
import antdvFix from 'vite-plugin-antdv-fix'

// https://vitejs.dev/config/
export default defineConfig({
  define: {
    'process.env': {
      NODE_ENV: 'production',
    },
  },
  build: {
    cssCodeSplit: true,
    lib: {
      entry: './packages/gt-antd1/index.js',
      name: 'GtAntd1',
      fileName: 'gt-antd1',
      formats: ['umd'],
    },
    outDir: 'dist/gt-antd1',
    rollupOptions: {
      external: ['vue', 'moment'], // 确保外部化处理那些你不想打包进库的依赖
      output: {
        // 在 UMD 构建模式下为这些外部化的依赖提供一个全局变量
        exports: 'named',
        globals: {
          vue: 'Vue',
          moment: 'moment',
        },
      },
    },
  },
  resolve: {
    alias: {
      'gt-vue2-components': resolve(__dirname, 'packages/gt-antd1'),
    },
  },
  plugins: [vue(), antdvFix()],
  optimizeDeps: {
    include: ['ant-design-vue'],
  },
  css: {
    preprocessorOptions: {
      less: {
        javascriptEnabled: true,
      },
    },
  },
})
